@@ -659,7 +659,7 @@ sub get_gentoo_runlevels
 sub get_gentoo_services_for_runlevel
 {
   my($runlevel) = @_;
-  my($raw_output) = Utils::File::run_backtick("rc-status -nocolor $runlevel");
+  my($raw_output) = Utils::File::run_backtick("rc-status --nocolor $runlevel");
   my(@raw_lines) = split(/\n/,$raw_output);
   my($line, $service);
   my(%services);
@@ -802,7 +802,7 @@ sub set_gentoo_service_status
 
   return if ($status == $old_status);
 
-  if ($action == $SERVICE_START)
+  if ($status == $SERVICE_START)
   {
     &Utils::File::run ("rc-update add $script $rl");
     &run_gentoo_script ($script, "start");
@@ -978,19 +978,31 @@ sub set_archlinux_service_status
   my ($script, $active) = @_;
   my $rcconf = '/etc/rc.conf';
   my ($daemons);
-  $daemons = &Utils::Parse::get_sh ($rcconf, "DAEMONS");
-  $daemons =~ s/[()]//;
 
-  if (($daemons =~ m/$script/) && !$active)
+  $daemons = &Utils::Parse::get_sh ($rcconf, "DAEMONS");
+  $daemons =~ s/[\(\)]//g;
+
+  # escape these chars
+  $script =~ s/([\\\.\^\$\*\+\?\{\}\[\]\(\)\|])/\\\1/g;
+  $notscript = "\!" . $script;
+
+  if (($daemons =~ m/$notscript/) && $active)
   {
-    $daemons =~ s/$script[ \t]*//;
+    # It was disabled, enable it
+    $daemons =~ s/$notscript/$script/g;
+  }
+  elsif (($daemons =~ m/$script/) && !$active)
+  {
+    # It was enabled, disable it
+    $daemons =~ s/$script/$notscript/g;
   }
   elsif (($daemons !~ m/$script/) && $active)
   {
-    $daemons =~ s/network/network $script/g;
+    $daemons .= " ".$script;
   }
 
-  &Utils::Replace::set_sh ($rcconf, "DAEMONS", "($daemons)", 1);
+  $daemons = "(" . $daemons . ")";
+  &Utils::Replace::set_sh ($rcconf, "DAEMONS", $daemons, 1);
   &run_rcng_script ($service, ($active) ? "start" : "stop");
 }
 
