@@ -144,7 +144,7 @@ sub set_timezone
     unlink $localtime;  # Important, since it might be a symlink.
     
     &Utils::Report::enter ();
-    $res = symlink ($tz, $localtime);
+    $res = copy ($tz, $localtime);
     &Utils::Report::leave ();
     return -1 unless $res;
     return 0;
@@ -165,8 +165,9 @@ sub get_dist
    "redhat-7.3"      => "redhat-6.2",
    "redhat-8.0"      => "redhat-6.2",
    "mandrake-9.0"    => "redhat-6.2",
-   "debian-3.0"      => "debian-3.0",
-   "ubuntu-7.04"     => "debian-3.0",
+   "debian-4.0"      => "debian-4.0",
+   "debian-testing"  => "debian-4.0",
+   "ubuntu-7.04"     => "debian-4.0",
    "suse-9.0"        => "redhat-6.2",
    "slackware-9.1.0" => "redhat-6.2",
    "gentoo"          => "redhat-6.2",
@@ -212,6 +213,19 @@ sub conf_get_parse_table
      ]
    },
 
+   "debian-4.0" =>
+   {
+     fn =>
+     {
+       TIMEZONE     => "/etc/timezone"
+     },
+     table =>
+     [
+      [ "local_time",   \&get_utc_time ],
+      [ "timezone",     \&Utils::Parse::get_first_line, TIMEZONE ],
+     ]
+   },
+
    "archlinux" =>
    {
      fn =>
@@ -283,6 +297,22 @@ sub conf_get_replace_table
      ]
    },
 
+   "debian-4.0" =>
+   {
+     fn =>
+     {
+       ZONEINFO     => "/usr/share/zoneinfo",
+       LOCAL_TIME   => "/etc/localtime",
+       TIMEZONE     => "/etc/timezone"
+     },
+     table =>
+     [
+      [ "timezone",    \&set_timezone, [LOCAL_TIME, ZONEINFO] ],
+      [ "timezone",    \&Utils::Replace::set_first_line, TIMEZONE ],
+      [ "local_time",  \&set_utc_time ],
+     ]
+   },
+
    "archlinux" =>
    {
      fn =>
@@ -364,4 +394,19 @@ sub set
   return $res;
 }
 
+sub get_files
+{
+  my (%dist_attrib, $fn, $f, $files);
+
+  %dist_attrib = &conf_get_replace_table ();
+  $fn = $dist_attrib {"fn"};
+
+  foreach $f (values %$fn)
+  {
+    push @$files, $f;
+  }
+
+  return $files;
+}
+
 1;
